@@ -41,6 +41,8 @@ from .constants import SLEEP_FIRMWARE_VERSION_UUID
 from .constants import SOFTWARE_BUILD_NUMBER_UUID
 from .constants import SOFTWARE_RELEASE_VERSION_UUID
 from .constants import START_RECORDING_TIME_INDEX_UUID
+from .constants import STIMULATION_PROTOCOL_UUID
+from .constants import STIMULATION_READINGS
 from .constants import TAMPER_FLAG_UUID
 from .constants import TIME_INDICES
 from .constants import TIME_OFFSETS
@@ -53,6 +55,7 @@ from .constants import TRIMMED_TIME_FROM_ORIGINAL_START_UUID
 from .constants import USER_ACCOUNT_ID_UUID
 from .constants import UTC_BEGINNING_DATA_ACQUISTION_UUID
 from .constants import UTC_BEGINNING_RECORDING_UUID
+from .constants import UTC_BEGINNING_STIMULATION_UUID
 from .constants import UTC_FIRST_REF_DATA_POINT_UUID
 from .constants import UTC_FIRST_TISSUE_DATA_POINT_UUID
 from .constants import UTC_TIMESTAMP_OF_FILE_VERSION_MIGRATION_UUID
@@ -152,4 +155,7 @@ __all__ = [
     "H5Wrapper",
     "SensorDataNotInFileError",
     "AxisDataForSensorNotInFileError",
+    "STIMULATION_PROTOCOL_UUID",
+    "STIMULATION_READINGS",
+    "UTC_BEGINNING_STIMULATION_UUID",
 ]
